@@ -22,6 +22,7 @@ import logging
 import math
 import mimetypes
 import os
+import re
 import time
 from collections import namedtuple
 from configparser import ConfigParser
@@ -53,6 +54,7 @@ Config = namedtuple("Config", ["api_id", "api_hash"])
 
 
 class Client:
+    INVITE_LINK_RE = re.compile(r"^(?:https?:\/\/)?t\.me\/joinchat\/(.+)$")
     DIALOGS_AT_ONCE = 100
 
     def __init__(self, session_name: str, test_mode: bool = False):
@@ -300,10 +302,6 @@ class Client:
                     continue
 
                 for message in d.messages:  # type: Message
-                    # Only search for Messages
-                    if not isinstance(message, Message):
-                        continue
-
                     is_this = peer_id == message.from_id or dialog.peer == message.to_id
 
                     if is_this:
@@ -388,7 +386,7 @@ class Client:
         else:
             try:
                 return (
-                    self.peers_by_username[chat_id.lower()]
+                    self.peers_by_username[chat_id.lower().strip("@")]
                     if isinstance(chat_id, str)
                     else self.peers_by_id[chat_id]
                 )
@@ -933,3 +931,57 @@ class Client:
                 limit=limit
             )
         )
+
+    def join_chat(self, chat_id: str):
+        match = self.INVITE_LINK_RE.match(chat_id)
+
+        if match:
+            return self.send(
+                functions.messages.ImportChatInvite(
+                    hash=match.group(1)
+                )
+            )
+        else:
+            resolved_peer = self.send(
+                functions.contacts.ResolveUsername(
+                    username=chat_id.lower().strip("@")
+                )
+            )
+
+            channel = InputPeerChannel(
+                channel_id=resolved_peer.chats[0].id,
+                access_hash=resolved_peer.chats[0].access_hash
+            )
+
+            return self.send(
+                functions.channels.JoinChannel(
+                    channel=channel
+                )
+            )
+
+    def leave_chat(self, chat_id: int or str, delete: bool = False):
+        peer = self.resolve_peer(chat_id)
+
+        if isinstance(peer, types.InputPeerChannel):
+            return self.send(
+                functions.channels.LeaveChannel(
+                    channel=self.resolve_peer(chat_id)
+                )
+            )
+        elif isinstance(peer, types.InputPeerChat):
+            r = self.send(
+                functions.messages.DeleteChatUser(
+                    chat_id=peer.chat_id,
+                    user_id=types.InputPeerSelf()
+                )
+            )
+
+            if delete:
+                self.send(
+                    functions.messages.DeleteHistory(
+                        peer=peer,
+                        max_id=0
+                    )
+                )
+
+            return r
